summaryrefslogtreecommitdiffstats
path: root/src/knutanalog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/knutanalog.cpp')
-rw-r--r--src/knutanalog.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/src/knutanalog.cpp b/src/knutanalog.cpp
index 9c0cab4..c3da789 100644
--- a/src/knutanalog.cpp
+++ b/src/knutanalog.cpp
@@ -153,7 +153,7 @@ void KNutAnalog::makeBackground (bool run) {
paintBackGround();
m_showBackGround = true;
if (run) {
- tqrepaint();
+ repaint();
}
}
@@ -165,7 +165,7 @@ void KNutAnalog::setText (TQString inscription, TQString text_up, bool run) {
if (run) {
paintBackGround();
m_showBackGround = true;
- tqrepaint();
+ repaint();
}
}
@@ -183,7 +183,7 @@ void KNutAnalog::setDefaultArcColor(bool run) {
if (run) {
paintBackGround();
m_showBackGround=true;
- tqrepaint();
+ repaint();
}
}
@@ -204,7 +204,7 @@ void KNutAnalog::addArc (double startOfCircle, double endOfCircle, int regColor,
if (run) {
paintBackGround();
m_showBackGround = true;
- tqrepaint ();
+ repaint ();
}
}
@@ -215,7 +215,7 @@ void KNutAnalog::delArc (bool run) {
if (run) {
paintBackGround();
m_showBackGround = true;
- tqrepaint ();
+ repaint ();
}
}
@@ -230,7 +230,7 @@ void KNutAnalog::setRange (int Astart, int Aend , bool run) {
if (run) {
paintBackGround();
m_showBackGround = true;
- tqrepaint ();
+ repaint ();
}
}
@@ -242,7 +242,7 @@ void KNutAnalog::setMember (int Count, bool run) {
if (run) {
paintBackGround();
m_showBackGround = true;
- tqrepaint ();
+ repaint ();
}
}
@@ -254,7 +254,7 @@ void KNutAnalog::setPointerColor (TQColor pointerColor, bool run ) {
paintPointer();
m_showPointer = true;
if (run) {
- tqrepaint ();
+ repaint ();
}
}
@@ -264,7 +264,7 @@ void KNutAnalog::repaintPointer ( bool run ) {
paintPointer();
m_showPointer = true;
if (run) {
- tqrepaint ();
+ repaint ();
}
}
@@ -277,7 +277,7 @@ void KNutAnalog::setFontColor (TQColor fontColor, bool run ) {
if (run) {
paintBackGround();
m_showBackGround = true;
- tqrepaint ();
+ repaint ();
}
}
@@ -288,7 +288,7 @@ void KNutAnalog::setScaleColor (TQColor scaleColor, bool run) {
if (run) {
paintBackGround();
m_showBackGround = true;
- tqrepaint ();
+ repaint ();
}
}
@@ -307,7 +307,7 @@ void KNutAnalog::setDigitalProcesing (int qualityOfPointer, bool run ) {
}
paintPointer();
m_showPointer = true; // pri jakemkoliv prekresleni prekreslime rucicku
- if (run) tqrepaint ();
+ if (run) repaint ();
}
@@ -320,7 +320,7 @@ void KNutAnalog::setPointer (double pointerValue, bool run ) {
if (run) {
// paintPointer();
m_showPointer = true; // pri jakemkoliv prekresleni prekreslime rucicku
- tqrepaint ();
+ repaint ();
}
}
}
@@ -333,26 +333,26 @@ void KNutAnalog::slotSetScaleFont(TQFont newScaleFont){
m_scaleFont = newScaleFont;
paintBackGround();
m_showBackGround=true;
- tqrepaint();
+ repaint();
}
void KNutAnalog::slotSetTextFont(TQFont newTextFont){
m_textFont = newTextFont;
paintBackGround();
- paintPointer(); // tqrepaint values if pointer
+ paintPointer(); // repaint values if pointer
m_showBackGround=true;
m_showPointer=true;
- tqrepaint();
+ repaint();
}
void KNutAnalog::slotSetAllFont(TQFont newAllFont){
m_scaleFont = newAllFont;
m_textFont = newAllFont;
paintBackGround();
- paintPointer(); // tqrepaint values if pointer
+ paintPointer(); // repaint values if pointer
m_showBackGround=true;
m_showPointer=true;
- tqrepaint();
+ repaint();
}
@@ -360,7 +360,7 @@ void KNutAnalog::repaintAll (void) {
paintBackGround();
m_showBackGround = true;
m_showPointer = true;
- tqrepaint ();
+ repaint ();
}